Learn R Programming

mulSEM (version 1.2)

Nimon21: Raw data used in Nimon, Joo, and Bontrager (2021)

Description

This dataset includes the raw data of 13 variables reported by Nimon, Joo, and Bontrager (2021).

Usage

Nimon21

Arguments

Format

A data frame with 13 variables.

References

Gu, F., & Cheung, M. W.-L. (2023). A Model-based approach to multivariate principal component regression: Selection of principal components and standard error estimates for unstandardized regression coefficients. British Journal of Mathematical and Statistical Psychology, 76(3), 605-622. tools:::Rd_expr_doi("10.1111/bmsp.12301")

Gu, F., Yung, Y.-F., Cheung, M. W.-L., Joo, B.-K., & Nimon, K. (2023). Statistical inference in redundancy analysis: A direct covariance structure modeling approach. Multivariate Behavioral Research, 58(5), 877-893. tools:::Rd_expr_doi("10.1080/00273171.2022.2141675")

Examples

Run this code
# \donttest{
data(Nimon21)

## Redundancy Analysis
rda(X_vars=c("AU", "CC", "CL", "CO", "DF", "FB", "GR", "MW"),
    Y_vars=c("IDE", "IEE", "IOCB", "IPR", "ITS"),
    data=Nimon21)

## Multivariate Principal Component Regression
mpcr(X_vars=c("AU", "CC", "CL", "CO", "DF", "FB", "GR", "MW"),
     Y_vars=c("IDE", "IEE", "IOCB", "IPR", "ITS"),
     pca="COR", pc_select=1,
     data=Nimon21)
# }

Run the code above in your browser using DataLab