| mpcr | R Documentation |
Conduct multivariate principal component regression
mpcr(
X_vars,
Y_vars,
data = NULL,
Cov = NULL,
Means = NULL,
numObs = NULL,
pca = c("COV", "COR"),
pc_select = NULL,
extraTries = 50,
...
)
X_vars |
A vector of characters of the X variables. |
Y_vars |
A vector of characters of the Y variables. |
data |
A data frame containing raw data. If NULL, |
Cov |
A covariance or correlation matrix. Required when |
Means |
An optional mean vector. Can be provided when |
numObs |
A sample size. Required when |
pca |
Whether principal component analysis is based on
unstandardized ( |
pc_select |
PCs selected in the regression analysis. For example,
|
extraTries |
This function calls |
... |
Additional arguments passed to either
|
This function conducts multivariate principal component regression using the OpenMx package. Missing data are handled with the full information maximum likelihood method when raw data are available. It provides standard errors for the estimates.
A list with class MPCR. It stores the model in OpenMx
objects. The fitted object is stored in mx.fit.
Mike W.-L. Cheung mikewlcheung@nus.edu.sg
Gu, F., & Cheung, M. W.-L. (2023). A model-based approach to multivariate principal component regression: Selection of principal components and standard error estimates for unstandardized regression coefficients. British Journal of Mathematical and Statistical Psychology, 76(3), 605-622. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/bmsp.12301")}
Nimon21
## Multivariate Principal Component Regression
mpcr(X_vars=c("AU", "CC", "CL", "CO", "DF", "FB", "GR", "MW"),
Y_vars=c("IDE", "IEE", "IOCB", "IPR", "ITS"),
pca="COR", pc_select=1,
data=Nimon21)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.