| cancorr | R Documentation |
This function conducts canonical correlation analysis using the OpenMx package. Missing data are handled with the full information maximum likelihood method when raw data are available. It provides standard errors for the estimates.
cancorr(
X_vars,
Y_vars,
data = NULL,
Cov = NULL,
numObs = NULL,
model = c("CORR-W", "CORR-L", "COV-W", "COV-L"),
extraTries = 50,
...
)
X_vars |
A vector of characters of the X variables. |
Y_vars |
A vector of characters of the Y variables. |
data |
A data frame containing raw data. If NULL, |
Cov |
A covariance or correlation matrix. Required when |
numObs |
A sample size. Required when |
model |
Four models defined in Gu, Yung, and Cheung (2019).
|
extraTries |
This function calls |
... |
Additional arguments passed to either
|
A list with class CanCorr. It stores the model in OpenMx
objects. The fitted object is stored in mx.fit.
cancorr expects the number of variables in Y_vars to be
equal to or greater than that in X_vars. If there are fewer in
Y_vars, you may swap between X_vars and Y_vars.
Mike W.-L. Cheung mikewlcheung@nus.edu.sg
Gu, F., Yung, Y.-F., & Cheung, M. W.-L. (2019). Four covariance structure models for canonical correlation analysis: A COSAN modeling approach. Multivariate Behavioral Research, 54(2), 192-223. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/00273171.2018.1512847")}
Thorndike00, sas_ex1
## Canonical Correlation Analysis
cancorr(X_vars=c("Weight", "Waist", "Pulse"),
Y_vars=c("Chins", "Situps", "Jumps"),
data=sas_ex1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.